# Disclaimer

This tool is provided _caveat emptor_ and relies on the public databases that it draws from.
If you have any issues with the resulting data - please refer your rage to the relevant providers
and don't shoot the messenger :)
